# API Reference

## Main Types

- `HistoryManager`
- `CachedHistoryManager`
- `OperationRegistry`
- `InMemoryStorage`
- `SQLiteStorage`
- `SessionRecord`
- `OperationRecord`
- `SessionStatus`

## Key Methods

- `HistoryManager.start_session(**context)`
- `HistoryManager.list_sessions(limit=None)`
- `HistoryManager.get_session(session_id)`
- `HistoryManager.get_operations(session_id)`
- `HistoryManager.undo_session(session_id, registry, mark_rolled_back=True, allow_multiple_undo=False)`
